/***********************************************************************************
FILE NAME  	: hwsetup.c
DESCRIPTION	: Hardware Setup functions

Copyright   : 2006 Renesas Technology Europe Ltd.
Copyright   : 2006 Renesas Technology Corporation.
              All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
27.03.2006 RTE-NPS First Release
************************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/

/***********************************************************************************
User Includes
***********************************************************************************/
/* sfr26a.h provides a structure to access all of the device registers. */
#include "sfr26a.h"

/* HTSdemodef.h provides common defines for widely used items. */
#include "HTSdemodef.h"

#include "hwsetup.h"

/***********************************************************************************
User Program Code Prototypes
***********************************************************************************/
/* These functions are private so their prototypes are defined locally */
void ConfigureOperatingFrequency(void);
void EnablePeripheralModules(void);
void ConfigurePortPins(void);

/***********************************************************************************
User Program Code 
***********************************************************************************/

/***********************************************************************************
Function Name: 	HardwareSetup
Description:	Sets up hardware
Parameters: none
Return value: none
***********************************************************************************/

void HardwareSetup(void)
{    
	ConfigureOperatingFrequency();

	ConfigurePortPins();

	EnablePeripheralModules();

}

/***********************************************************************************
End of function HardwareSetup
***********************************************************************************/

/***********************************************************************************
Function Name: 	ConfigureOperatingFrequency
Description:	Sets up operating speed
Parameters: none
Return value: none
***********************************************************************************/
void ConfigureOperatingFrequency(void)
{
    unsigned int count = 10000;

	/* enable access to processor mode registers */
	prc1 = 1;                       

	/* 2 wait states for sfr access...this is the reset value necessary for >16Mhz operation, 
	   can be set to 1 wait for <=16Mhz */
    pm20 = 0;                       
                                       
    /* disable access to processor mode registers */
	prc1 = 0;                       

    /* configure and switch main clock to PLL at 20MHz */
	/* enable access to clock registers */
    prc0 = 1;                       

	/* set to hi-drive Xin, divide by 1 */
    cm1 = 0x20;                     

    /* set to main clock using divide by 1 */
	cm0 = 0x08;                     

    /* switch to Xin */
	cm21 = 0;                       


	/* configure PLL to x4 */
    plc0 = 0x12;                    
    
	/* enable PLL */
	plc0 = 0x92;                    
    
	/* wait for PLL to stabilize (20mS maximum, 100,000 cycles @5Mhz)
       this decrement with no optimization is 12 cycles each (10,000*12 cycles=120,000=24mS) */
    while(count > 0) count--;       

    /* switch to PLL */
	cm11 = 1;                       

    /* disable access to clock registers */
	prc0 = 0;                       
 
}
/***********************************************************************************
End of function ConfigureOperatingFrequency
***********************************************************************************/

/***********************************************************************************
Function Name: 	EnablePeripheralModules
Description:	Enables Peripheral Modules before use
Parameters: none
Return value: none
***********************************************************************************/
void EnablePeripheralModules(void)
{
	/* All modules are active in the M16C device */
}
/***********************************************************************************
End of function EnablePeripheralModules
***********************************************************************************/

/***********************************************************************************
Function Name: 	ConfigurePortPins
Description:	Configures port pins 
Parameters: none
Return value: none
***********************************************************************************/
void ConfigurePortPins(void)
{
/* Port pins default to inputs. To ensure safe initialisation set the pin states
before changing the data direction registers. This will avoid any unintentional
state changes on the external ports.
Many peripheral modules will override the setting of the port registers. Ensure
that the state is safe for external devices if the internal peripheral module is
disabled or powered down. */

/* General device configuration */
	/* Enables next instruction to set pacr */
	prcr = 0x04;

	/* Set to 48 pin chip */	
	pacr = 0x04;

/* Switch Port configuration : All pins are inputs by default */

/* LED Port configuration */
	ENABLE_LEDS;			

}
/***********************************************************************************
End of function ConfigurePortPins
***********************************************************************************/
